@@ -86,11 +86,11 @@ check lv_field $vg/raid1 size "56.50m"
 lvremove -ff $vg
 
 # 1 metadata LV = 1 extent
-# 1 image = 37 extents
-# 5 images = 190 extents = 95.00m = lv_size
+# 1 image = 37 extents   = 18.5m
+# 5 images = 185 extents = 92.5m = lv_size
+lvs -a  $vg
 lvcreate --type raid5 -i 5 -l 100%FREE -an -Zn -n raid5 $vg
-should check lv_field $vg/raid5 size "95.00m"
-#FIXME: Currently allocates incorrectly at 87.50m
+check lv_field $vg/raid5 size "92.50m"
 lvremove -ff $vg
 
 # 1 image = 37+38 extents
@@ -102,8 +102,7 @@ lvremove -ff $vg
 # 1 image = 37 extents
 # 4 images = 148 extents = 74.00m = lv_size
 lvcreate --type raid6 -i 4 -l 100%FREE -an -Zn -n raid6 $vg
-should check lv_field $vg/raid6 size "74.00m"
-#FIXME: Currnently allocates incorrectly at 70.00m
+check lv_field $vg/raid6 size "74.00m"
 lvremove -ff $vg
 
 ###
