@@ -9,12 +9,14 @@
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-. lib/test
+. lib/inittest
+
+test -e LOCAL_LVMPOLLD && skip
 
 which mkfs.ext2 || skip
 
 extend() {
-	lvextend --use-policies --config "activation { snapshot_extend_threshold = $1 }" $vg/snap
+	lvextend --use-policies --config "activation { snapshot_autoextend_threshold = $1 }" $vg/snap
 }
 
 write() {
@@ -27,13 +29,13 @@ percent() {
 	get lv_field $vg/snap snap_percent | cut -d. -f1
 }
 
-aux prepare_dmeventd
+# no dmeventd running in this test, testing --use-policies
 aux prepare_vg 2
 
-lvcreate -l 8 -n base $vg
+lvcreate -aey -L24 -n base $vg
 mkfs.ext2 "$DM_DEV_DIR/$vg/base"
 
-lvcreate -s -l 4 -n snap $vg/base
+lvcreate -s -L16 -n snap $vg/base
 mkdir mnt
 
 write 1 4096
