@@ -45,4 +45,10 @@ check_
 test -e LOCAL_LVMETAD && lvremove $vg/boo # FIXME trigger a write :-(
 check_ not
 
+aux disable_dev "$dev1"
+vgreduce --removemissing --force $vg
+aux enable_dev "$dev1"
+vgs 2>&1 | grep 'Removing PV'
+vgs 2>&1 | not grep 'Removing PV'
+
 vgremove -ff $vg
